# Reference

Here's a list with a link to a file for every class in the wrapper because I'm *that* lazy:

- [AsyncClient](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/asyncclient.md)
- [Band](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/band.md)
- [BandLeaderboard](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/bandleaderboard.md)
- [Brawler](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/brawler.md)
- [Client](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/client.md)
- [Errors](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/errors.md)
- [Id](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/id.md)
- [InfoBrawler](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/infobrawler.md)
- [Map](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/map.md)
- [Mode](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/mode.md)
- [Member](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/member.md)
- [MinimalBand](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/minimalband.md)
- [Player](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/player.md)
- [PlayerLeaderboard](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/playerleaderboard.md)
- [RankedBand](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/rankedband.md)
- [RankedPlayer](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/rankedplayer.md)
- [StaticData](https://github.com/umbresp/brawlstars/blob/master/brawlstars/docs/staticdata.md)

